==> luna3-2.13.60.tar.gz: luna3-2.13.60/luna3/accounts/http_objs.py <==
"""
Module implements classes for standard structures.
"""
from dataclasses import dataclass, field
from typing import Dict, Optional, Set

try:
    from typing import Literal
except ImportError:
    from typing_extensions import Literal

from stringcase import snakecase


@dataclass
class EmitEvents:
    """
    Emit events token permissions
    Attributes:
        allowed: whether emit events request are allowed
        whiteList: IDs of handlers allowed for use
        blackList: IDs of handlers denied for use
    """

    allowed: Literal[0, 1] = 1
    whiteList: Optional[Set[str]] = None
    blackList: Optional[Set[str]] = None

    def asDict(self) -> Dict:
        """Get dictionary representation"""
        return {snakecase(key): value for key, value in self.__dict__.items() if value is not None}


@dataclass
class TokenPermissions:
    """
    Token permissions class

    Attributes:
        face: face permissions
        list: list permissions
        event: event permissions
        attribute: attribute permissions
        handler: handler permissions
        verifier: verifier permissions
        task: task permissions
        faceSample: face sample permissions
        bodySample: body sample permissions
        images: image permissions
        objects: objects permissions
        token: token permissions
        resources: resources permissions
        emitEventsWhiteList: handler ids white list for `emit events` requests
        emitEventsBlackList: handler ids black list for `emit events` requests
    """

    face: Set[Literal["creation", "view", "modification", "deletion", "matching"]] = ()
    list: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    event: Set[Literal["creation", "view", "matching"]] = ()
    attribute: Set[Literal["creation", "view", "modification", "deletion", "matching"]] = ()
    handler: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    verifier: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    task: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    faceSample: Set[Literal["creation", "view", "deletion"]] = ()
    bodySample: Set[Literal["creation", "view", "deletion"]] = ()
    token: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    image: Set[Literal["creation", "view", "deletion"]] = ()
    object: Set[Literal["creation", "view", "deletion"]] = ()
    resources: Set[Literal["iso", "sdk", "liveness"]] = ()
    emitEvents: EmitEvents = field(default_factory=EmitEvents)
    lambdas: Set[Literal["creation", "view", "modification", "deletion"]] = ()

    def asDict(self) -> Dict:
        """Get dictionary representation without None values"""
        res = {"emit_events": {}}
        for key, value in self.__dict__.items():
            if value is None:
                continue
            if hasattr(value, "asDict"):
                res["emit_events"] = value.asDict()
            else:
                res[snakecase(key)] = value
        return res

==> luna3-2.13.71.tar.gz: luna3-2.13.71/luna3/accounts/http_objs.py <==
"""
Module implements classes for standard structures.
"""
from copy import deepcopy
from dataclasses import dataclass, field
from typing import Dict, Optional, Set

try:
    from typing import Literal
except ImportError:
    from typing_extensions import Literal

from stringcase import snakecase


@dataclass
class EmitEvents:
    """
    Emit events token permissions
    Attributes:
        allowed: whether emit events request are allowed
        whiteList: IDs of handlers allowed for use
        blackList: IDs of handlers denied for use
    """

    allowed: Literal[0, 1] = 1
    whiteList: Optional[Set[str]] = None
    blackList: Optional[Set[str]] = None

    def asDict(self) -> Dict:
        """Get dictionary representation"""
        return {snakecase(key): value for key, value in self.__dict__.items() if value is not None}


@dataclass
class TokenPermissions:
    """
    Token permissions class

    Attributes:
        face: face permissions
        list: list permissions
        event: event permissions
        attribute: attribute permissions
        handler: handler permissions
        verifier: verifier permissions
        task: task permissions
        faceSample: face sample permissions
        bodySample: body sample permissions
        token: token permissions
        image: image permissions
        object: objects permissions
        resources: resources permissions
        emitEvents: handler IDs list for events generation request
        lambdas: lambdas permissions
        custom: custom permissions dict
    """

    face: Set[Literal["creation", "view", "modification", "deletion", "matching"]] = ()
    list: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    event: Set[Literal["creation", "view", "matching"]] = ()
    attribute: Set[Literal["creation", "view", "modification", "deletion", "matching"]] = ()
    handler: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    verifier: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    task: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    faceSample: Set[Literal["creation", "view", "deletion"]] = ()
    bodySample: Set[Literal["creation", "view", "deletion"]] = ()
    token: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    image: Set[Literal["creation", "view", "deletion"]] = ()
    object: Set[Literal["creation", "view", "deletion"]] = ()
    resources: Set[Literal["iso", "sdk", "liveness"]] = ()
    emitEvents: EmitEvents = field(default_factory=EmitEvents)
    lambdas: Set[Literal["creation", "view", "modification", "deletion"]] = ()
    custom: Dict[str, Set[Literal["creation", "view", "modification", "deletion"]]] = field(default_factory=dict)

    def asDict(self) -> Dict:
        """Get dictionary representation without None values"""
        res = {"emit_events": {}}
        data = deepcopy(self.__dict__)
        data.update(data.pop("custom"))
        for key, value in data.items():
            if value is None:
                continue
            if hasattr(value, "asDict"):
                res["emit_events"] = value.asDict()
            else:
                res[snakecase(key)] = value
        return res
